@@ -21,41 +21,33 @@ from urllib.parse import urlsplit
 
 
 
-def formaturl(maindata,host,microserviceid):
-    hostarr=host.split(":")
-    hbuf=hostarr[0]
-    hbuf=hbuf.lower()
-    domain=''
-    if hbuf=='https':
-        domain=hbuf[8:]
-    else:
-        domain=hbuf[7:]
+def formaturl(maindata,host,microserviceid,prehost,port):
 
     if len(microserviceid)>0:    
-      mainurl=hostarr[0] + "://" + domain +"/" + microserviceid + "/?hyperpredict=" + maindata
+      mainurl=prehost + "://" + host +  ":" + str(port) +"/" + microserviceid + "/?hyperpredict=" + maindata
     else:
-      mainurl=hostarr[0] + "://" + domain +"/?hyperpredict=" + maindata
+      mainurl=prehost + "://" + host + ":" + str(port) +"/?hyperpredict=" + maindata
         
     return mainurl
     
 async def tcp_echo_client(message, loop,host,port,usereverseproxy,microserviceid):
 
-    if usereverseproxy:
-        geturl=formaturl(message,host,microserviceid) #host contains http:// or https://
-        message="GET %s\n\n" % geturl 
+    hostarr=host.split(":")
+    hbuf=hostarr[0]
+   # print(hbuf)
+    hbuf=hbuf.lower()
+    domain=''
+    if hbuf=='https':
+       domain=host[8:]
     else:
-        hostarr=host.split(":")
-        hbuf=hostarr[0]
-        hbuf=hbuf.lower()
-        domain=''
-        if hbuf=='https':
-          domain=hbuf[8:]
-        else:
-          domain=hbuf[7:]
-        host=domain  
+       domain=host[7:]
+    host=domain  
 
-    reader, writer = await asyncio.open_connection(host, port,
-                                                   loop=loop)
+    if usereverseproxy:
+        geturl=formaturl(message,host,microserviceid,hbuf,port) #host contains http:// or https://
+        message="GET %s\n\n" % geturl 
+
+    reader, writer = await asyncio.open_connection(host, port, loop=loop)
         
     mystr=str.encode(message)
     writer.write(mystr)
@@ -73,6 +65,10 @@ def hyperpredictions(maadstoken,pkey,theinputdata,host,port,usereverseproxy=0,mi
       buf2=buf2.replace("\n", "").strip()
       buf2=buf2.replace("\r", "").strip()
       theinputdata=buf2
+
+    if usereverseproxy:
+       theinputdata=urllib.parse.quote(theinputdata)
+  
     value="%s,[%s],%s" % (pkey,theinputdata,maadstoken)
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_client(value, loop,host,port,usereverseproxy,microserviceid))
